@@ -77,7 +77,8 @@ DAISIE_sim_core_trait_dep <- function(
     )
     timeval_and_dt <- calc_next_timeval(
       max_rates = rates,
-      timeval = timeval
+      timeval = timeval,
+      total_time = total_time
     )
     timeval <- timeval_and_dt$timeval
 
